# Hurry Curry! - a game about cooking
# Copyright (C) 2025 Hurry Curry! contributors
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, version 3 of the License only.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
class_name FreezerModel
extends Node3D

@onready var anim_player: AnimationPlayer = $AnimationPlayer
@onready var light_1: OmniLight3D = $OmniLight3D
@onready var light_2: OmniLight3D = $OmniLight3D2
@onready var light_3: OmniLight3D = $OmniLight3D3

func open():
	light_1.set_visible_(true)
	light_2.set_visible_(true)
	light_3.set_visible_(true)
	anim_player.play("open")

func _on_animation_player_animation_finished(_anim_name: StringName) -> void:
	light_1.set_visible_(false)
	light_2.set_visible_(false)
	light_3.set_visible_(false)
