# Hurry Curry! - a game about cooking
# Copyright (C) 2025 Hurry Curry! contributors
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, version 3 of the License only.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
class_name Bun
extends Item

var steam: CPUParticles3D = preload("res://map/items/steam.tscn").instantiate()

func _init(owned_by_: Node3D):
	super(owned_by_)
	base.add_child(load("res://map/items/bun.tscn").instantiate())
	steam.position.y += .1
	steam.color = Color(.6, .6, .6, .4)
	base.add_child(steam)

func progress(position_: float, speed: float, warn: bool):
	super(position_, speed, warn)
	steam.emitting = warn

func finish():
	super()
	steam.emitting = false
