# Hurry Curry! - a game about cooking
# Copyright (C) 2025 Hurry Curry! contributors
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, version 3 of the License only.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
extends GameSetting
class_name SettingsRoot

var children: Array
func _init(new_children: Array):
	super("root")
	children = new_children
	for c in children:
		c.set_parent(null)

func create_row():
	var row = TabContainer.new()
	row.size_flags_vertical = Control.SIZE_EXPAND_FILL
	for r in children: row.add_child(r.create_row())
	return row

func load(d: Dictionary):
	for c in children: c.load(d)

func save(d: Dictionary):
	for c in children: c.save(d)
